# encoding: utf-8
require 'spec_helper'

describe Actions::AddExamplesToTestCasesDirectory do
  let(:examples_directory) { File.join(working_directory, 'test_cases.d', 'examples') }

  let(:repo) do
    Rugged::Repository.init_at(git_repo)
  end
  context '#initialize' do
    it 'requires a path' do
      Actions::AddExamplesToTestCasesDirectory.new(examples_directory)
    end
  end

  context '#run' do
    it 'runs the action' do
      action = Actions::AddExamplesToTestCasesDirectory.new(examples_directory)
      silence(:stderr) do
        action.run
      end

      expect(path_exists?('test_cases.d/examples')).to be_truthy
    end

    it 'respects existing path' do
      create_directory('test_cases.d/examples')

      action = Actions::AddExamplesToTestCasesDirectory.new(examples_directory)

      result = capture(:stderr) do
        ProxyTester.ui_logger.level = :info
        action.run
      end

      expect(result).to include('already')
    end

    it 'does overwrite existing files if forced to' do
      create_directory('test_cases.d/examples')

      action = Actions::AddExamplesToTestCasesDirectory.new(examples_directory, force: true)

      result = capture(:stderr) do
        ProxyTester.ui_logger.level = :info
        action.run
      end

      expect(result).to include('Creating')
    end
  end
end
