# encoding: utf-8
require 'spec_helper'

describe Actions::AddTestCase do
  let(:remote_repository_path) { File.join(working_directory, 'git_repo.git') }

  context '#initialize' do
    it 'requires a source and a destination' do
      repo = GitRepository.create(remote_repository_path)
      repo.add_content('file.txt', 'asdf1')

      remote_repository = double('RemoteRepository')
      allow(remote_repository).to receive(:source).and_return("file://#{remote_repository_path}")

      expect {
        Actions::AddTestCase.new(remote_repository, working_directory)
      }.not_to raise_error
    end
  end

  context '#run' do
    it 'runs the action' do
      repo = GitRepository.create(remote_repository_path)
      repo.add_content('file.txt', 'asdf1')

      remote_repository = double('RemoteRepository')
      allow(remote_repository).to receive(:to_string).and_return("file://#{remote_repository_path}")
      allow(remote_repository).to receive(:source).and_return("file://#{remote_repository_path}")
      allow(remote_repository).to receive(:base).and_return(::File.basename(remote_repository_path, '.git'))

      action = Actions::AddTestCase.new(remote_repository, working_directory)
      silence(:stderr) do
        action.run
      end

      expect(path_exists?('git_repo')).to be_truthy
    end

    it 'respects existing path' do
      repo = GitRepository.create(remote_repository_path)
      repo.add_content('file.txt', 'asdf1')

      remote_repository = double('RemoteRepository')
      allow(remote_repository).to receive(:to_string).and_return("file://#{remote_repository_path}")
      allow(remote_repository).to receive(:source).and_return("file://#{remote_repository_path}")
      allow(remote_repository).to receive(:base).and_return(::File.basename(remote_repository_path, '.git'))

      create_directory(::File.join(::File.basename(remote_repository_path, '.git'), '.git'))

      action = Actions::AddTestCase.new(remote_repository, working_directory)

      result = capture(:stderr) do
        ProxyTester.ui_logger.level = :info
        action.run
      end

      expect(result).to include('already')
    end

    it 'does remove existing path if forced to' do
      repo = GitRepository.create(remote_repository_path)
      repo.add_content('file.txt', 'asdf1')

      remote_repository = double('RemoteRepository')
      allow(remote_repository).to receive(:to_string).and_return("file://#{remote_repository_path}")
      allow(remote_repository).to receive(:source).and_return("file://#{remote_repository_path}")
      allow(remote_repository).to receive(:base).and_return(::File.basename(remote_repository_path, '.git'))

      create_directory(::File.join(::File.basename(remote_repository_path, '.git'), '.git'))

      action = Actions::AddTestCase.new(remote_repository, working_directory, force: true)

      result = capture(:stderr) do
        ProxyTester.ui_logger.level = :info
        action.run
      end

      expect(result).to include('Add')
    end
  end
end
