# encoding: utf-8
require 'spec_helper'

describe CapybaraProxyPac do
  let(:valid_pac_file1) do <<-EOS.strip_heredoc.chomp
                           function FindProxyForURL(url, host) {
                             return "PROXY localhost:3128";
                           }
  EOS
  end

  context 'all' do
    it 'handles exceptions for file not found' do
      pac = CapybaraProxyPac.new
      expect { pac.pac_file = 'asdf' }.to raise_error Exceptions::PacFileNotFound
    end

    it 'handles missing url' do
      pac = CapybaraProxyPac.new
      pac.pac_file = create_file('proxy.pac', valid_pac_file1)
      expect { pac.host }.not_to raise_error
    end
  end

  context '#pac_file' do
    let(:pac_file) { create_file 'proxy.pac', valid_pac_file1 }

    it 'reads from file' do
      pac = CapybaraProxyPac.new
      pac.pac_file = pac_file
      expect(pac.pac_file).to eq pac_file
    end

    it 'reads from file url' do
      pac = CapybaraProxyPac.new
      pac.pac_file = 'file://' + pac_file
      expect(pac.pac_file).to eq pac_file
    end

    it 'reads from url' do
      url =  'http://pac-host.example.com/proxy.pac'
      stub_request(:any, url).to_return(body: valid_pac_file1)

      pac = CapybaraProxyPac.new
      pac.pac_file = url
      expect(pac.pac_file).to eq url
    end
  end

  context '#host' do
    it 'returns host for url' do
      file = create_file 'proxy.pac', valid_pac_file1

      pac = CapybaraProxyPac.new
      pac.pac_file = file
      pac.url = 'http://www.heise.de'

      expect(pac.host).to eq('localhost')
    end
  end

  context '#port' do
    it 'returns port for url' do
      file = create_file 'proxy.pac', valid_pac_file1

      pac = CapybaraProxyPac.new
      pac.pac_file = file
      pac.url = 'http://www.heise.de'

      expect(pac.port).to eq('3128')
    end
  end

  context '#verbatim' do
    it 'verbatim output' do
      file = create_file 'proxy.pac', valid_pac_file1

      pac = CapybaraProxyPac.new
      pac.pac_file = file
      pac.url = 'http://www.heise.de'

      expect(pac.verbatim).to eq('PROXY localhost:3128')
    end

    it 'handles not set file' do
      pac = CapybaraProxyPac.new
      expect { pac.verbatim }.not_to raise_error
    end
  end
end
