# encoding: utf-8
require 'fedux_org_stdlib/environment'

module ProxyTester
  module SpecHelper
    module Environment
      include FeduxOrgStdlib::Environment

      private

      def set_stdin(obj)
        $stdin = obj
      end

      def set_stderr(obj)
        $stderr = obj
      end

      def set_stdout(obj)
        $stdout = obj
      end

      def get_stdin
        $stdin
      end

      def get_stderr
        $stderr
      end

      def get_stdout
        $stdout
      end

      public

      def mock_io(io, *args, &block)
        raise RuntimeError, "Unsupported io: #{io}, allowed: stderr, stdin, stdout" unless [:stderr, :stdout, :stdin].include? io

        old_io = send("get_#{io}")

        io_obj = send("set_#{io}", StringIO.new)
        io_obj.puts(args.shift) until args.blank?
        io_obj.rewind

        block.call
      ensure
        io_obj = send("set_#{io}", old_io)
      end
    end
  end
end

RSpec.configure do |c|
  c.include ProxyTester::SpecHelper::Environment
  c.before(:suite) do
    %w{
      http_proxy
      https_proxy
      HTTP_PROXY
      HTTPS_PROXY
    }.each { |var| ENV.delete(var) }
  end
end

